## 期货合约信息表

接口：fut_basic

描述：获取期货合约列表数据

限量：单次最大10000

积分：用户需要至少2000积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| exchange | str | Y | 交易所代码 CFFEX-中金所 DCE-大商所 CZCE-郑商所 SHFE-上期所 INE-上海国际能源交易中心 GFEX-广州期货交易所 |
| fut_type | str | N | 合约类型 (1 普通合约 2主力与连续合约 默认取全部) |
| fut_code | str | N | 标准合约代码，如白银AG、AP鲜苹果等 |
| list_date | str | N | 上市开始日期(格式YYYYMMDD，从某日开始以来所有合约） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 合约代码 |
| symbol | str | Y | 交易标识 |
| exchange | str | Y | 交易市场 |
| name | str | Y | 中文简称 |
| fut_code | str | Y | 合约产品代码 |
| multiplier | float | Y | 合约乘数(只适用于国债期货、指数期货) |
| trade_unit | str | Y | 交易计量单位 |
| per_unit | float | Y | 交易单位(每手) |
| quote_unit | str | Y | 报价单位 |
| quote_unit_desc | str | Y | 最小报价单位说明 |
| d_mode_desc | str | Y | 交割方式说明 |
| list_date | str | Y | 上市日期 |
| delist_date | str | Y | 最后交易日期 |
| d_month | str | Y | 交割月份 |
| last_ddate | str | Y | 最后交割日 |
| trade_time_desc | str | N | 交易时间说明 |

接口示例

```python
pro = ts.pro_api('your token')

df = pro.fut_basic(exchange='DCE', fut_type='1', fields='ts_code,symbol,name,list_date,delist_date')
```

数据示例

```python
ts_code  symbol      name   list_date    delist_date
0      P0805.DCE   P0805   棕榈油0805  20071029    20080516
```